@@ -25,10 +25,10 @@ from textwrap import indent
 import click
 from boltons.cacheutils import cachedproperty
 from boltons.iterutils import flatten
-from boltons.strutils import indent
+from boltons.strutils import strip_ansi
 from boltons.typeutils import classproperty
 
-from . import logger, strip_ansi
+from . import logger
 from .bitbar import run
 from .platform import CURRENT_OS_ID
 from .version import parse_version
@@ -39,7 +39,7 @@ CLI_FORMATS = frozenset(['plain', 'fragments', 'bitbar'])
 
 class CLIError(Exception):
 
-    """ An error occured when running package manager CLI. """
+    """ An error occurred when running package manager CLI. """
 
     def __init__(self, code, output, error):
         """ The exception internally keeps the result of CLI execution. """
@@ -240,15 +240,22 @@ class PackageManager:
             output = strip_ansi(output)
             output = output if output else None
 
+        # Non-successful run.
         if code and error:
+            # Produce an exception and eventually raise it.
             exception = CLIError(code, output, error)
             if self.raise_on_cli_error:
                 raise exception
-            logger.error(error)
+            # Accumulate errors.
             self.cli_errors.append(exception)
 
+        # Log <stdout> and <stderr> output.
         if output:
             logger.debug(indent(output, '  '))
+        if error:
+            # Non-fatal error messages are logged as warnings.
+            log_func = logger.error if code else logger.warning
+            log_func(indent(error, '  '))
 
         return output
 
@@ -260,10 +267,17 @@ class PackageManager:
 
     def sync(self):
         """ Refresh local manager metadata from remote repository. """
+        if self.sync.__func__.__qualname__ == PackageManager.sync.__qualname__:
+            logger.warning(f"Sync not implemented for {self.id}.")
+            return
         logger.info(f"Sync {self.id} package info...")
 
     def cleanup(self):
         """ Remove left-overs and unused packages. """
+        if (self.cleanup.__func__.__qualname__ ==
+                PackageManager.cleanup.__qualname__):
+            logger.warning(f"Cleanup not implemented for {self.id}.")
+            return
         logger.info(f"Cleanup {self.id}...")
 
     @property
@@ -328,22 +342,30 @@ class PackageManager:
 
     @staticmethod
     def render_cli(cmd, cli_format='plain'):
-        """ Return a formatted CLI as string in the provided format. """
+        """ Return a formatted CLI in the requested format.
+
+        * ``plain`` returns a simple string
+        * ``fragments`` returns a list of strings
+        * ``bitbar`` returns a CLI with parameters formatted into the bitbar
+        dialect.
+        """
         assert isinstance(cmd, list)
         assert cli_format in CLI_FORMATS
-        cmd = list(map(str, cmd))  # Serialize Path instances.
-        if cli_format != 'fragments':
-            cmd = ' '.join(cmd)
-            if cli_format == 'bitbar':
-                cmd = PackageManager.render_bitbar_cli(cmd)
-        return cmd
+        cmd = map(str, flatten(cmd))  # Serialize Path instances.
 
-    @staticmethod
-    def render_bitbar_cli(full_cli):
-        """ Format a bash-runnable full-CLI with parameters into bitbar schema.
-        """
-        cmd, params = full_cli.strip().split(' ', 1)
-        bitbar_cli = "bash={}".format(cmd)
-        for index, param in enumerate(params.split(' ')):
-            bitbar_cli += " param{}={}".format(index + 1, param)
+        if cli_format == 'fragments':
+            return list(cmd)
+
+        if cli_format == 'plain':
+            return ' '.join(cmd)
+
+        # Renders the CLI into BitBar dialect.
+        bitbar_cli = ''
+        for index, param in enumerate(cmd):
+            if index == 0:
+                bitbar_cli += "bash={}".format(param)
+            else:
+                if '=' in param:
+                    param = "\\\"{}\\\"".format(param)
+                bitbar_cli += " param{}={}".format(index, param)
         return bitbar_cli
