@@ -25,11 +25,12 @@ import click
 import pytest
 import simplejson as json
 from boltons.iterutils import flatten
+from boltons.strutils import strip_ansi
 from cli_helpers.tabular_output import TabularOutputFormatter
 
-from .conftest import MANAGER_IDS, run_cmd, unless_windows
-from .. import __version__, logger, strip_ansi
-from ..cli import RENDERING_MODES, WINDOWS_MODE_BLACKLIST, cli
+from .. import __version__, logger
+from ..cli import RENDERING_MODES, WINDOWS_MODE_BLACKLIST
+from .conftest import MANAGER_IDS, unless_windows
 
 """ Common tests for all CLI basic features and templates for subcommands. """
 
@@ -170,6 +171,10 @@ class CLISubCommandTests:
                 # Common "not found" warning message.
                 "warning: Skip unavailable {} manager.".format(
                     mid) in result.stderr,
+                # Common "not implemented" optional command warning message.
+                bool(re.search(
+                    r"warning: (Sync|Cleanup) not implemented for {}.".format(
+                        mid), result.stderr)),
                 # Stats line at the end of output.
                 "{}: ".format(mid) in result.stdout.splitlines(
                     )[-1] if result.stdout else '',
@@ -294,8 +299,17 @@ class CLITableTests:
         """ Check default rendering is fancy_grid. """
         result = invoke(subcmd)
         assert result.exit_code == 0
+
         expected = self.expected_renderings['fancy_grid'][0]
-        assert expected in result.stdout
+
+        # If no package found, check that no table gets rendered. Else, check
+        # the selected mode is indeed rendered in <stdout>, so the CLI result
+        # can be grep-ed.
+        if result.stdout.startswith("0 package total ("):
+            assert expected not in result.stdout
+        else:
+            assert expected in result.stdout
+
         assert expected not in result.stderr
 
     @pytest.mark.parametrize('mode,expected,conflict', [
@@ -309,9 +323,15 @@ class CLITableTests:
         result = invoke('--output-format', mode, subcmd)
         assert result.exit_code == 0
 
-        # Check the selected mode is indeed rendered in <stdout>, so the CLI
-        # result can be grep-ed.
-        assert expected in result.stdout
+        # If no package found, check that no table gets rendered. Else, check
+        # the selected mode is indeed rendered in <stdout>, so the CLI result
+        # can be grep-ed.
+        if result.stdout.startswith("0 package total ("):
+            # CSV mode will match on comma.
+            if mode != 'csv':
+                assert expected not in result.stdout
+        else:
+            assert expected in result.stdout
 
         # Collect all possible unique traces from all possible rendering modes.
         blacklist = {
